diff_children_custom

Function diff_children_custom 

pub fn diff_children_custom<T>(
    old_children: &mut Vec<Tree>,
    new_children: &mut [T],
    diff: impl Fn(&mut Tree, &mut T),
    new_state: impl Fn(&T) -> Tree,
)
Reconciles the children of the tree with the provided list of widgets using custom logic both for diffing and creating new widget state.